@@ -30,3 +30,14 @@ class LearnSproutClientException(LearnSproutHTTPException):
 class LearnSproutServerException(LearnSproutHTTPException):
   """ Class for HTTP 5xx errors thrown by the **LearnSproutClient**. """
   name = "LS Server Error"
+
+def error_from_json(err_json):
+  """
+    Generates the appropriate error based on a response's status code.
+  """
+  if "status_code" in err_json:
+    error_code = err_json["status_code"]
+    if error_code >= 400 and error_code < 500:
+      return LearnSproutClientException(error_code, err_json["message"], err_json["uri"])
+    elif error_code >= 500:
+      return LearnSproutServerException(error_code, err_json["message"], err_json["uri"])
