@@ -7,9 +7,10 @@ from student import StudentCollection
 from term import TermCollection
 from attendance import AttendanceCollection
 from course_grade import CourseGradeCollection
+from enrollment import EnrollmentCollection
 
 class Organization(ResourceInstance):
-  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection]
+  subresources = [CourseCollection, SchoolCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection, EnrollmentCollection]
 
 
 class OrganizationCollection(ResourceCollection):
