@@ -101,7 +101,7 @@ class ResourceCollection(Resource):
     result = self.instance_from_json(response)
     return result
 
-  def iter_all(self, since=None):
+  def iter_all(self, since=None, params={}):
     """
     Returns an **IterableResult** which allows an access to all the
     **ResourceInstance** that are contained in this collection.
@@ -109,7 +109,6 @@ class ResourceCollection(Resource):
     The since parameter is used to filter out **ResourceInstances** by their
     time_updated property.
     """
-    params = {}
     if since:
       params["since"] = since
     return IterableResult(self.owning_client, self.instance_from_json, self.uri, params)
