@@ -6,9 +6,10 @@ from teacher import TeacherCollection
 from term import TermCollection
 from attendance import AttendanceCollection
 from course_grade import CourseGradeCollection
+from enrollment import EnrollmentCollection
 
 class School(ResourceInstance):
-  subresources = [CourseCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection]
+  subresources = [CourseCollection, SectionCollection, StudentCollection, TeacherCollection, TermCollection, AttendanceCollection, CourseGradeCollection, EnrollmentCollection]
 
 
 class SchoolCollection(ResourceCollection):
