@@ -1,7 +1,9 @@
 from resource import ResourceInstance, ResourceCollection
+from attendance import AttendanceCollection
+from course_grade import CourseGradeCollection
 
 class Section(ResourceInstance):
-  pass
+  subresources = [AttendanceCollection, CourseGradeCollection]
 
 
 class SectionCollection(ResourceCollection):
